@@ -56,10 +56,7 @@ if(plot_type==0):
         
         # harmonic things
         D = util.get_D(k, K,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
-        eigvals = np.linalg.eigvalsh(D)
-        idx = np.argsort(eigvals)
-        eigvals = eigvals[idx]
-        omegas = np.sqrt(eigvals)/2/np.pi
+        eigvals, eigvecs, omegas = util.get_eigvals_eigvec(D)
 
         freq_disp = omegas
         print(' Creating plots for k point = ', k_scaled)
