@@ -241,7 +241,8 @@ def get_eigvals_eigvec(D):
     eigvals, eigvecs = eigvals[idx], eigvecs[:,idx]
     omegas = np.sqrt(eigvals, dtype=complex)/(2*np.pi)
     omegas = omegas.real - omegas.imag
-    return eigvals, eigvecs, omegas
+    eigvecs_ortho, R = np.linalg.qr(eigvecs)
+    return eigvals, eigvecs_ortho, omegas
 
 def get_eigvals(D):
     eigvals = np.linalg.eigvalsh(D)
